﻿  CREATE SCHEMA REPRESENTANTES;
  CREATE SCHEMA CASILLAS;
  CREATE SCHEMA GEOGRAFICO;
  CREATE SCHEMA PARTIDOSPOLITICOS;
  DROP SCHEMA PUBLIC;

-------------------------------------------------------------------------------------------------------------------------
--------------------------------   ESQUEMA GEOGRAFICO    --------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------
--DROP TABLE GEOGRAFICO.ESTADOS;  
  CREATE TABLE GEOGRAFICO.ESTADOS (
	 ID_ESTADO 			DECIMAL (2) PRIMARY KEY, 
	 NOMBRE_ESTADO 			VARCHAR(50), 
	 ABREVIATURA 		VARCHAR(10)) ;
 COMMENT ON TABLE GEOGRAFICO.Estados  IS 'Catálogo|Tabla que contiene a los estados válidos dentro de un país.';
	COMMENT ON COLUMN GEOGRAFICO.Estados.ID_ESTADO IS '|Identificador del estado.';
   	COMMENT ON COLUMN GEOGRAFICO.Estados.NOMBRE_ESTADO IS '|Este campo hace referencia al NOMBRE asociado al identificador del estado.';
    COMMENT ON COLUMN GEOGRAFICO.Estados.ABREVIATURA IS '|Este campo hace referencia al NOMBRE de la ABREVIATURA asociado al identificador del estado.';

--DROP TABLE GEOGRAFICO.DISTRITOS_FEDERALES;   	
  CREATE TABLE GEOGRAFICO.DISTRITOS_FEDERALES (
	 ID_ESTADO  					DECIMAL (2)  REFERENCES GEOGRAFICO.ESTADOS (ID_ESTADO), 
	 ID_DISTRITO_FEDERAL 			DECIMAL (2), 
	 CABECERA_DISTRITAL_FEDERAL 	VARCHAR(50),
	 PRIMARY KEY (ID_ESTADO, ID_DISTRITO_FEDERAL) );
 COMMENT ON TABLE GEOGRAFICO.DISTRITOS_FEDERALES  IS 'Catálogo|Tabla que contiene a los distritos federales válidos dentro de un país.';
	COMMENT ON COLUMN GEOGRAFICO.DISTRITOS_FEDERALES.ID_ESTADO IS '|Identificador del estado.';
	COMMENT ON COLUMN GEOGRAFICO.DISTRITOS_FEDERALES.ID_DISTRITO_FEDERAL IS '|Identificador del distrito federal asociado a un estado.';
   	COMMENT ON COLUMN GEOGRAFICO.DISTRITOS_FEDERALES.CABECERA_DISTRITAL_FEDERAL IS '|Este campo hace referencia al NOMBRE asociado al identificador del distrito federal';

 
--DROP TABLE GEOGRAFICO.DISTRITOS_LOCALES;   	
  CREATE TABLE GEOGRAFICO.DISTRITOS_LOCALES (
	 ID_ESTADO  				DECIMAL (2)  REFERENCES GEOGRAFICO.Estados (ID_ESTADO), 
	 ID_DISTRITO_LOCAL  		DECIMAL (2), 
	 CABECERA_DISTRITAL_LOCAL 	VARCHAR(50),
	 PRIMARY KEY (ID_ESTADO, ID_DISTRITO_LOCAL) );
 COMMENT ON TABLE GEOGRAFICO.DISTRITOS_LOCALES  IS 'Catálogo|Tabla que contiene a los distritos locales  válidos dentro de un país.';
	COMMENT ON COLUMN GEOGRAFICO.DISTRITOS_LOCALES.ID_ESTADO IS '|Identificador del estado.';
	COMMENT ON COLUMN GEOGRAFICO.DISTRITOS_LOCALES.ID_DISTRITO_LOCAL IS '|Identificador del distrito local asociado a un estado.';
   	COMMENT ON COLUMN GEOGRAFICO.DISTRITOS_LOCALES.CABECERA_DISTRITAL_LOCAL IS '|Este campo hace referencia al NOMBRE asociado al identificador del distrito local';

--DROP TABLE GEOGRAFICO.MUNICIPIOS;   	
  CREATE TABLE GEOGRAFICO.MUNICIPIOS (
	 ID_ESTADO 				DECIMAL (2)  REFERENCES GEOGRAFICO.Estados (ID_ESTADO), 
	 ID_MUNICIPIO  			DECIMAL (3), 
	 NOMBRE_MUNICIPIO 		VARCHAR(50),
	 PRIMARY KEY (ID_ESTADO, ID_MUNICIPIO) );
 COMMENT ON TABLE GEOGRAFICO.MUNICIPIOS  IS 'Catálogo|Tabla que contiene a los Municipio  válidos dentro de un país.';
	COMMENT ON COLUMN GEOGRAFICO.MUNICIPIOS.ID_ESTADO IS '|Identificador del estado.';
	COMMENT ON COLUMN GEOGRAFICO.MUNICIPIOS.ID_MUNICIPIO IS '|Identificador del Municipio asociado a un estado.';
   	COMMENT ON COLUMN GEOGRAFICO.MUNICIPIOS.NOMBRE_MUNICIPIO IS '|Este campo hace referencia al NOMBRE asociado al identificador del Municipio.';
    
--DROP TABLE GEOGRAFICO.SECCIONES;   	
  CREATE TABLE GEOGRAFICO.SECCIONES (
	 ID_ESTADO  			DECIMAL (2)  REFERENCES GEOGRAFICO.ESTADOS (ID_ESTADO), 
	 ID_DISTRITO_FEDERAL  	DECIMAL (2), 
	 ID_DISTRITO_LOCAL  	DECIMAL (2), 
	 ID_MUNICIPIO  			DECIMAL (3),
	 SECCION  				DECIMAL (5),
	 TIPO  					VARCHAR(1),
	 CONSTRAINT PK_SECCIONES PRIMARY KEY (ID_ESTADO, SECCION) ,
	 CONSTRAINT UQ1_SECCIONES UNIQUE (ID_ESTADO,ID_DISTRITO_FEDERAL, ID_DISTRITO_LOCAL, ID_MUNICIPIO, SECCION) ,
	 CONSTRAINT FK1_DISTRITOS_FEDERALES FOREIGN KEY(ID_ESTADO, ID_DISTRITO_FEDERAL)  REFERENCES GEOGRAFICO.DISTRITOS_FEDERALES (ID_ESTADO, ID_DISTRITO_FEDERAL) ,
	 CONSTRAINT FK2_DISTRITOS_LOCALES FOREIGN KEY(ID_ESTADO, ID_DISTRITO_LOCAL)  REFERENCES GEOGRAFICO.DISTRITOS_LOCALES (ID_ESTADO, ID_DISTRITO_LOCAL) ,
	 CONSTRAINT FK3_MUNICIPIOS FOREIGN KEY(ID_ESTADO, ID_MUNICIPIO)  REFERENCES GEOGRAFICO.MUNICIPIOS (ID_ESTADO, ID_MUNICIPIO)  );
 COMMENT ON TABLE GEOGRAFICO.SECCIONES  IS 'Catálogo|Tabla que contiene las secciones validas dentro de un país.';
	COMMENT ON COLUMN GEOGRAFICO.SECCIONES.ID_ESTADO IS '|Identificador del estado.';
    COMMENT ON COLUMN GEOGRAFICO.SECCIONES.ID_DISTRITO_FEDERAL IS '|Identificador del DISTRITO FEDERAL asociado a un estado.';
    COMMENT ON COLUMN GEOGRAFICO.SECCIONES.ID_DISTRITO_LOCAL IS '|Identificador del DISTRITO LOCAL asociado a un estado.';
	COMMENT ON COLUMN GEOGRAFICO.SECCIONES.ID_MUNICIPIO IS '|Identificador del MUNICIPIO asociado a un estado.';
   	COMMENT ON COLUMN GEOGRAFICO.SECCIONES.SECCION IS '| Número de la SECCION asociado a un estado, distrito federal , distrito local , municipio  ';
    COMMENT ON COLUMN GEOGRAFICO.SECCIONES.TIPO IS '| TIPO de la SECCION U.- Urbana , M.-Mixta.';
    

-------------------------------------------------------------------------------------------------------------------------
--------------------------------   ESQUEMA PARTIDOSPOLITICOS   --------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------

--DROP TABLE PARTIDOSPOLITICOS.PARTIDOS;
  CREATE TABLE PARTIDOSPOLITICOS.PARTIDOS(
	 ID_ESTADO  			 DECIMAL (2)   , 
	 TIPO_ASOCIACION         DECIMAL(1,0) NOT NULL, 
	 ID_PARTIDO_CANDIDATO    DECIMAL(6,0) NOT NULL, 
	 NOMBRE                  VARCHAR(70) NOT NULL, 
	 SIGLAS                  VARCHAR(50) NOT NULL, 
	 CONSTRAINT PK_PARTIDOS PRIMARY KEY ( ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO ) ,
	 CONSTRAINT FK1_ESTADOS FOREIGN KEY(ID_ESTADO) REFERENCES GEOGRAFICO.ESTADOS (ID_ESTADO));
 COMMENT ON TABLE PARTIDOSPOLITICOS.PARTIDOS IS   'Catálogo|Contiene informacion de los partidos políticos federales.' ;
	COMMENT ON COLUMN PARTIDOSPOLITICOS.PARTIDOS.TIPO_ASOCIACION IS  '1.- Partido Politico, 4.- Candidatura Independiente|Identificador del TIPO de Asociacion Politica en la que podran ser registrados los representantes.' ;
	COMMENT ON COLUMN PARTIDOSPOLITICOS.PARTIDOS.ID_PARTIDO_CANDIDATO IS  '|Identificador del Partido Politico o Candidato Independiente para el que pueden ser registrados los representantes.' ;
	COMMENT ON COLUMN PARTIDOSPOLITICOS.PARTIDOS.NOMBRE IS  'NOMBRE del Partido Politico o Candidato Independiente.' ;
	COMMENT ON COLUMN PARTIDOSPOLITICOS.PARTIDOS.SIGLAS IS  'SIGLAS del Partido Político o Candidato Independiente.' ;
	 
-------------------------------------------------------------------------------------------------------------------------
--------------------------------   ESQUEMA CASILLAS    --------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------
--DROP TABLE CASILLAS.CASILLAS ;
  CREATE TABLE CASILLAS.CASILLAS (    
	 ID_ESTADO 							DECIMAL (2) NOT NULL, 
	 ID_DISTRITO_FEDERAL 				DECIMAL(2,0) NOT NULL, 
	 SECCION 							DECIMAL(5) NOT NULL, 
	 TIPO_CASILLA                		VARCHAR(6) NOT NULL, 
	 APROBACION_CASILLA_CONSEJO 		CHAR(1), 
	 FECHA_APROBACION_CASILLA_CONSEJO 	DATE, 
	 USUARIO 							VARCHAR(50) NOT NULL , 
	 FECHA_HORA 						TIMESTAMP (6) NOT NULL, 
	 CONSTRAINT PK_CASILLAS PRIMARY KEY ( ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA),
	 CONSTRAINT FK1_CASILLAS FOREIGN KEY(ID_ESTADO,SECCION) REFERENCES GEOGRAFICO.SECCIONES(ID_ESTADO,SECCION) ,
	 CONSTRAINT CHECK_TIPO_CASILLA CHECK ( TIPO_CASILLA LIKE  'B1' OR TIPO_CASILLA LIKE 'C1' OR TIPO_CASILLA LIKE 'C2' OR  TIPO_CASILLA LIKE 'C3') ) ; 
 COMMENT ON TABLE CASILLAS.CASILLAS  IS 'Captura|Almacena la información de las casilla aprobadas por el consejo, las cuales son las que son utilizadas durante la Jornada Electoral.';
  	COMMENT ON COLUMN CASILLAS.CASILLAS.ID_ESTADO IS '|Identificador del ESTADO.';
   	COMMENT ON COLUMN CASILLAS.CASILLAS.ID_DISTRITO_FEDERAL IS '|Este campo hace referencia al ID_DISTRITO_FEDERAL.';
   	COMMENT ON COLUMN CASILLAS.CASILLAS.SECCION IS '|Número de la sección.';
   	COMMENT ON COLUMN CASILLAS.CASILLAS.TIPO_CASILLA IS 'B.- Básica, C.- Contigua |TIPO de casilla.'; 
   	COMMENT ON COLUMN CASILLAS.CASILLAS.APROBACION_CASILLA_CONSEJO IS 'S.- Si; N.- No|Casilla aprobada por el consejo.';
   	COMMENT ON COLUMN CASILLAS.CASILLAS.FECHA_APROBACION_CASILLA_CONSEJO IS 'DD/MM/YYYY| Fecha en que fue aprobada por la junta la casilla.';
   	COMMENT ON COLUMN CASILLAS.CASILLAS.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN CASILLAS.CASILLAS.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF |Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
 
-------------------------------------------------------------------------------------------------------------------------
--------------------------------   ESQUEMA REPRESENTANTES    --------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------
--DROP TABLE REPRESENTANTES.REPRESENTANTES_DATOS 
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_DATOS (  
	 ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL ,
	 CLAVE_ELECTOR            CHAR(18) NOT NULL, 
	 NOMBRE                   VARCHAR(35), 
	 APELLIDO_PATERNO         VARCHAR(35), 
	 APELLIDO_MATERNO         VARCHAR(35), 
	 SEXO                     CHAR(1), 
	 DOMICILIO                VARCHAR(200), 
	 USUARIO                  VARCHAR(50) NOT NULL , 
	 FECHA_HORA               TIMESTAMP (6) NOT NULL ,
	 CONSTRAINT PK_REPRESENTANTES_DATOS  PRIMARY KEY (ID_REPRESENTANTE_DATOS , CLAVE_ELECTOR) );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_DATOS  IS 'Captura|Tabla que contiene a los representantes que se dan de alta por cada uno de los diferentes partidos.';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.ID_REPRESENTANTE_DATOS  IS ' |Identificador de la tabla.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.CLAVE_ELECTOR  IS ' |Identificador de la tabla y número de Credencial de Elector.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.NOMBRE IS '|NOMBRE del representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.APELLIDO_PATERNO IS '|Apellido Paterno del representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.APELLIDO_MATERNO IS '|Apellido Materno del representante.';   
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.SEXO  IS 'H.- Hombre, M.- Mujer|Identifiacdor del genero de la persona.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.DOMICILIO IS '|Domicilio del Representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
        

--DROP TABLE REPRESENTANTES.REPRESENTANTES_PRELIMINARES
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_PRELIMINARES (    
	 ID_REPRESENTANTE_PRE     DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL ,
	 ID_ESTADO                DECIMAL(2,0) NOT NULL , 
	 ID_DISTRITO_FEDERAL      DECIMAL(2,0) NOT NULL , 
	 TIPO_ASOCIACION          DECIMAL(1,0) NOT NULL , 
	 ID_PARTIDO_CANDIDATO     DECIMAL(6,0) NOT NULL , 
	 CLAVE_ELECTOR            CHAR(18 ) NOT NULL , 
	 USUARIO         		  VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA        		  TIMESTAMP (6) NOT NULL , 
	 CONSTRAINT PK_REPRESENTANTES_PRE PRIMARY KEY (ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS) ,
	 CONSTRAINT FK1_REPRESENTANTES_DATOS FOREIGN KEY (ID_REPRESENTANTE_DATOS, CLAVE_ELECTOR) 
	 REFERENCES   REPRESENTANTES.REPRESENTANTES_DATOS(ID_REPRESENTANTE_DATOS, CLAVE_ELECTOR) ,
 	 CONSTRAINT  FK2_PARTIDOS FOREIGN KEY (ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO) 
	 REFERENCES   PARTIDOSPOLITICOS.PARTIDOS(ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO)  );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_PRELIMINARES  IS 'Captura|Tabla que contiene a los representantes preliminares que se dan de alta por cada uno de los diferentes partidos.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.ID_REPRESENTANTE_PRE IS '|Identificador del representante del partido político.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.ID_ESTADO IS '|Identificador del estado (REPRESENTANTES.Representantes) (CASILLAS.CASILLAS).';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES; o bien, el ID_DISTRITO_LOCAL de la tabla DISTRITOS_LOCALES del esquema de GEOGRAFICO.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.TIPO_ASOCIACION IS '1.- Partido Politico, 4.- Candidatura Independiente|Identificador del TIPO de Asociacion Politica en la que podran ser registrados los representantes.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.ID_PARTIDO_CANDIDATO IS '|Identificador del Partido Politico o Candidato Independiente para el que pueden ser registrados los representantes.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.CLAVE_ELECTOR IS '|Número de Credencial de Elector.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
  
--DROP TABLE REPRESENTANTES.REPRESENTANTES_CASILLA;
 CREATE TABLE REPRESENTANTES.REPRESENTANTES_CASILLA (  
	ID_REPRESENTANTE_PRE     DECIMAL(10,0) NOT NULL ,
	ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL , 
	ID_ESTADO                DECIMAL(2,0) NOT NULL , 
	ID_DISTRITO_FEDERAL      DECIMAL(2,0) NOT NULL , 
	CALIDAD_REPRESENTANTE    CHAR(1), 
	SECCION                  DECIMAL(5) NOT NULL, 
	TIPO_CASILLA             VARCHAR(6) NOT NULL ,
	USUARIO         		 VARCHAR(50 ) NOT NULL , 
	FECHA_HORA        		 TIMESTAMP (6) NOT NULL , 
	CONSTRAINT PK_REPRESENTANTES_CASILLA PRIMARY KEY (ID_REPRESENTANTE_PRE ) ,
	CONSTRAINT FK1_REPRESENTANTES_PRELIMINARES FOREIGN KEY( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS) REFERENCES  
	REPRESENTANTES.REPRESENTANTES_PRELIMINARES  (  ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS) ON DELETE CASCADE,
	CONSTRAINT FK2_CASILLAS FOREIGN KEY( ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA) REFERENCES  
	CASILLAS.CASILLAS ( ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA) , 
	CONSTRAINT UQ1_RESTRICCION_REPRE_CASILLA UNIQUE ( ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS, ID_ESTADO, ID_DISTRITO_FEDERAL , CALIDAD_REPRESENTANTE ,SECCION , TIPO_CASILLA )  );
COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_CASILLA  IS 'Captura| Tabla donde se Almacena la informacion de los representantes asociados a las casillas.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.ID_REPRESENTANTE_PRE IS '|Identificador del representantes preliminar (REPRESENTANTES.REPRESENTANTES_PRELIMINARES).';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.ID_ESTADO IS '|Identificador del estado (REPRESENTANTES.Representantes) (CASILLAS.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES; o bien, el ID_DISTRITO_LOCAL de la tabla DISTRITOS_LOCALES del esquema de GEOGRAFICO.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.SECCION IS '|Número de la sección (CASILLAS.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.TIPO_CASILLA IS ' B.- Básica, C.- Contigua |TIPO de casilla. (CASILLAS.CASILLAS).'; 
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.CALIDAD_REPRESENTANTE IS '1;propietario1,  2;propietario2,  3;suplente.|Nivel del representante.';
  	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
  
--DROP TABLE REPRESENTANTES.REPRESENTANTES_GENERALES;
 CREATE TABLE REPRESENTANTES.REPRESENTANTES_GENERALES (  
	ID_REPRESENTANTE_PRE     DECIMAL(10,0) NOT NULL ,
	ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL , 
	ID_ESTADO                DECIMAL(2,0) NOT NULL , 
	ID_DISTRITO_FEDERAL      DECIMAL(2,0) NOT NULL , 
	USUARIO         		 VARCHAR(50 ) NOT NULL , 
	FECHA_HORA        		 TIMESTAMP (6) NOT NULL , 
	CONSTRAINT PK_REPRESENTANTES_GENERALES PRIMARY KEY (ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS , ID_ESTADO, ID_DISTRITO_FEDERAL ) ,
	CONSTRAINT FK1_REPRESENTANTES_PRELIMINARES FOREIGN KEY( ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS) REFERENCES  
	REPRESENTANTES.REPRESENTANTES_PRELIMINARES  ( ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS) ON DELETE CASCADE    );
COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_GENERALES  IS 'Captura| Tabla donde se Almacena la informacion de los representantes asociados a los distrito federales';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES.ID_REPRESENTANTE_PRE IS '|Identificador del representantes preliminar (REPRESENTANTES.REPRESENTANTES_PRELIMINARES).';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES.ID_ESTADO IS '|Identificador del estado (REPRESENTANTES.Representantes) (CASILLAS.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES; o bien, el ID_DISTRITO_LOCAL de la tabla DISTRITOS_LOCALES del esquema de GEOGRAFICO.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
  
--DROP TABLE REPRESENTANTES.REPRESENTANTES_ACREDITADOS;
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_ACREDITADOS (	
	 ID_REPRESENTANTE_ACRE 			DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_PRE 			DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_DATOS   		DECIMAL(10,0) NOT NULL , 
	 FECHA_ACREDITACION 			DATE, 
	 ID_RESPONBLE_ACRE 				DECIMAL(10,0) NOT NULL , 
	 HORA_ACREDITACION 				TIME WITHOUT TIME ZONE NOT NULL , 
	 ACTIVO            				CHAR(1) NOT NULL   DEFAULT 'T'  , 
	 USUARIO 						VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA 					TIMESTAMP (6) NOT NULL ,
	 CONSTRAINT PK_REPRESENTANTES_ACREDITADOS PRIMARY KEY ( ID_REPRESENTANTE_ACRE ) ,
	 CONSTRAINT FK1_REPRESENTANTES_PRELIMINARES FOREIGN KEY( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS ) 
	 REFERENCES   REPRESENTANTES.REPRESENTANTES_PRELIMINARES( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS ) ON DELETE CASCADE , 
	 CONSTRAINT UQ1_RESTRICCION_REPRE_ACRE UNIQUE (  ID_REPRESENTANTE_DATOS   ) );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_ACREDITADOS  IS 'Captura|Tabla que contiene a los representantes acreditados que se dan de alta por cada uno de los diferentes partidos.';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.ID_REPRESENTANTE_ACRE  IS '|Identificador del representante del partido político.';  
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.FECHA_ACREDITACION  IS '|Fecha de la acreditacion. .';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.ID_RESPONBLE_ACRE  IS 'O.- OPLE, C.- CD| Identifica quien acredita al representante, OPLE o por Consejo Distrital.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.HORA_ACREDITACION IS 'HH:MM:SS|Hora y minutos con segundo en que se acredita a el representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.ACTIVO IS '|Bandera para saber si el representante esta activo o no para la eleccion.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
 
--DROP TABLE REPRESENTANTES.ASISTENCIAS  
  CREATE TABLE REPRESENTANTES.ASISTENCIAS   (    
	 ID_REPRESENTANTE_ACRE 			DECIMAL(10,0) NOT NULL , 
	 ID_ESTADO 						DECIMAL(2,0) NOT NULL , 
	 ID_DISTRITO_FEDERAL 			DECIMAL(2,0) NOT NULL , 	
	 SECCION				 		DECIMAL(5) NOT NULL , 
	 TIPO_CASILLA          			VARCHAR(6) NOT NULL , 
	 FIRMA_INICIO 					CHAR(1), 
	 FIRMA_FIN 						CHAR(1), 
	 FIRMA_COMPUTO 					CHAR(1), 	
	 PRESENCIA_INICIO 				CHAR(1), 
	 PRESENCIA_FIN 					CHAR(1), 
	 PRESENCIA_COMPUTO 				CHAR(1), 		
	 USUARIO 						VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA 					TIMESTAMP (6) NOT NULL , 
	 CONSTRAINT PK_ASISTENCIA PRIMARY KEY ( ID_REPRESENTANTE_ACRE , ID_ESTADO, ID_DISTRITO_FEDERAL,  SECCION, TIPO_CASILLA ),
	 CONSTRAINT FK1_CASILLAS FOREIGN KEY  ( ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA ) 
	 REFERENCES CASILLAS.CASILLAS  (   ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA ) ,
	 CONSTRAINT FK2_REPRESENTANTES_ACREDITADOS FOREIGN KEY (  ID_REPRESENTANTE_ACRE)  REFERENCES REPRESENTANTES.REPRESENTANTES_ACREDITADOS  (  ID_REPRESENTANTE_ACRE) ,
	 CONSTRAINT CHECK_FIRMA_INICIO CHECK (FIRMA_INICIO IN ('N', 'A', 'P', 'E')) , 
	 CONSTRAINT CHECK_FIRMA_FIN CHECK (FIRMA_FIN IN ('N', 'A', 'P', 'E')) , 
	 CONSTRAINT CHECK_FIRMA_COMPUTO CHECK (FIRMA_COMPUTO IN ('N', 'A', 'P', 'E')) );
 COMMENT ON TABLE REPRESENTANTES.ASISTENCIAS  IS 'Captura|Tabla que contiene la asistencia de los representantes de casillas y generales, y se registran 3 tipos de asistencias al inicio, fin y escrutinio y computo';
	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.ID_REPRESENTANTE_ACRE IS '|Identificador del representante del partido político. (REPRESENTANTES.REPRESENTANTES_ACREDITADOS).';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.ID_ESTADO IS '|Identificador del estado.  (REPRESENTANTES.REPRESENTANTES_ACREDITADOS). (Casillas2015.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES;';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.SECCION IS '|Número de la sección .';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.TIPO_CASILLA IS ' B.- Básica, C.- Contigua |TIPO de casilla. (CASILLAS.CASILLAS).; ';
	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.FIRMA_INICIO IS 'I |Determina que asistio el representante al inicio de la jornada electoral.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.FIRMA_FIN IS 'F |Determina que asistio el representante al final de la jornada electoral.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.FIRMA_COMPUTO IS 'C |Determina que asistio el representante al escrutinio y computo de los votos.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.PRESENCIA_INICIO IS 'N - NOMBRE F- NOMBRE y firma|Indica si el representante registro su NOMBRE o su NOMBRE y firma al inicio de la jornada.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.PRESENCIA_FIN IS 'N - NOMBRE F- NOMBRE y firma|Indica si el representante registro su NOMBRE o su NOMBRE y firma al final de la jornada.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.PRESENCIA_COMPUTO IS 'N - NOMBRE F- NOMBRE y firma|Indica si el representante registro su NOMBRE o su NOMBRE y firma durante el escrutinio y computo.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.ASISTENCIAS.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';

--DROP TABLE REPRESENTANTES.RESPONSABLES_ACREDITACION  
  CREATE TABLE REPRESENTANTES.RESPONSABLES_ACREDITACION (
  	 ID_RESPONBLE_ACRE    		DECIMAL(2,0) NOT NULL , 
	 ID_ESTADO					DECIMAL(2,0) NOT NULL , 
	 TIPO_ASOCIACION 			DECIMAL(1,0) NOT NULL , 
	 ID_PARTIDO_CANDIDATO 		DECIMAL(6,0) NOT NULL , 
	 NOMBRE 					VARCHAR(50 ), 
	 APELLIDO_PATERNO 			VARCHAR(40 ), 
	 APELLIDO_MATERNO 			VARCHAR(40 ), 
	 USUARIO 					VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA 				TIMESTAMP (6) NOT NULL , 
	 CONSTRAINT PK_RESPONSABLES_ACREDITACION PRIMARY KEY (ID_RESPONBLE_ACRE, ID_ESTADO, TIPO_ASOCIACION, ID_PARTIDO_CANDIDATO) ,
	 CONSTRAINT FK1_PARTIDOS FOREIGN KEY (  ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO)  REFERENCES PARTIDOSPOLITICOS.PARTIDOS  ( ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO)  );
 COMMENT ON TABLE REPRESENTANTES.RESPONSABLES_ACREDITACION  IS 'Captura|Tabla que contiene los datos de los responsables de acreditar a los representantes de los partidos políticos';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.ID_ESTADO IS '|Identificador del estado.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.TIPO_ASOCIACION IS '1.- Partido Politico, 4.- Candidatura Independiente|Identificador del TIPO de Asociacion Politica en la que podran ser registrados los representantes.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.ID_PARTIDO_CANDIDATO IS '|Identificador del Partido Politico o Candidato Independiente para el que  pueden ser registrados los representantes.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.NOMBRE IS '|NOMBRE del representante que acreditara ante el consejo.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.APELLIDO_PATERNO IS '|Apellido Paterno del representante que acreditara ante el consejo.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.APELLIDO_MATERNO IS '|Apellido Materno del representante que acreditara ante el consejo.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
 COMMENT ON COLUMN REPRESENTANTES.RESPONSABLES_ACREDITACION.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';


--DROP TABLE REPRESENTANTES.REPRESENTANTES_SUSTITUCION ;     
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_SUSTITUCION  (	
	 ID_SUSTITUCION 					DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_ACRE 				DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_ACRE_1			DECIMAL(10,0) NOT NULL , 
	 ACREDITADO_POR				 		CHAR(1) NOT NULL , 
	 HORA_ACREDITACION 					VARCHAR(8) , 
	 USUARIO 							VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA 						TIMESTAMP (6) NOT NULL , 
	 CONSTRAINT PK_REPRESENTANTES_SUSTITUCION PRIMARY KEY ( ID_SUSTITUCION) ,
	 CONSTRAINT FK1_REPRESENTANTES_ACREDITADOS FOREIGN KEY ( ID_REPRESENTANTE_ACRE)  REFERENCES
	 REPRESENTANTES.REPRESENTANTES_ACREDITADOS  (ID_REPRESENTANTE_ACRE) ,
	 CONSTRAINT FK2_REPRESENTANTES_ACREDITADOS FOREIGN KEY ( ID_REPRESENTANTE_ACRE_1)  REFERENCES
	 REPRESENTANTES.REPRESENTANTES_ACREDITADOS  (ID_REPRESENTANTE_ACRE)   );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_SUSTITUCION  IS 'Captura|Tabla que contiene los identificadores de los representantes que son sometidos al proceso de sustitución.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.ID_SUSTITUCION IS '|Identificador unico y consecutivo para las sustituciones.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.ID_REPRESENTANTE_ACRE IS '|Identificador del representante del partido político.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.ID_REPRESENTANTE_ACRE_1 IS '|Identificador del representante del partido político que se va  a acreditar.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.ACREDITADO_POR IS 'O.- OPLE, C.- CD|Identifica quien acredita al representante, OPLE o por Consejo Distrital.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.HORA_ACREDITACION IS 'HH:MM:SS|Hora y minutos con segundo en que se acredita a el representante.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_SUSTITUCION.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
 
--DROP TABLE REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO    
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO  ( 
  	 ID_HISTORICO  			  DECIMAL(10,0) NOT NULL , 
  	 TIPO_OPERACION  		  CHAR(1), 
	 ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL ,
	 CLAVE_ELECTOR            CHAR(18) NOT NULL, 
	 NOMBRE                   VARCHAR(35), 
	 APELLIDO_PATERNO         VARCHAR(35), 
	 APELLIDO_MATERNO         VARCHAR(35), 
	 SEXO                     CHAR(1), 
	 DOMICILIO                VARCHAR(200), 
	 USUARIO                  VARCHAR(50) NOT NULL , 
	 FECHA_HORA               TIMESTAMP (6) NOT NULL ,
	 CONSTRAINT PK_REPRESENTANTES_DATOS_HISTORICO  PRIMARY KEY (ID_HISTORICO) );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO  IS 'Historico|Tabla de captura la cual contiene un registro de cada una de las operaciones realizadas sobre la tabla representantes_datos y genera un histórico de los datos de cada una de sus columnas';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.ID_HISTORICO  IS ' |Identificador de la tabla.';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.TIPO_OPERACION  IS ' |Tipo de operacion que se realizo al registro.';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.ID_REPRESENTANTE_DATOS  IS ' |Identificador de la tabla principal.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.CLAVE_ELECTOR  IS ' |Identificador de la tabla y número de Credencial de Elector.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.NOMBRE IS '|NOMBRE del representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.APELLIDO_PATERNO IS '|Apellido Paterno del representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.APELLIDO_MATERNO IS '|Apellido Materno del representante.';   
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.SEXO  IS 'H.- Hombre, M.- Mujer|Identifiacdor del genero de la persona.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.DOMICILIO IS '|Domicilio del Representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_DATOS_HISTORICO.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
        

--DROP TABLE REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO 
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO  (    
  	 ID_HISTORICO  			  DECIMAL(10,0) NOT NULL , 
  	 TIPO_OPERACION  		  CHAR(1), 
	 ID_REPRESENTANTE_PRE     DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL ,
	 ID_ESTADO                DECIMAL(2,0) NOT NULL , 
	 ID_DISTRITO_FEDERAL      DECIMAL(2,0) NOT NULL , 
	 TIPO_ASOCIACION          DECIMAL(1,0) NOT NULL , 
	 ID_PARTIDO_CANDIDATO     DECIMAL(6,0) NOT NULL , 
	 CLAVE_ELECTOR            CHAR(18 ) NOT NULL , 
	 USUARIO         		  VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA        		  TIMESTAMP (6) NOT NULL , 
	 CONSTRAINT PK_REPRESENTANTES_PRE_HISTORICO PRIMARY KEY (ID_HISTORICO) ,
	 CONSTRAINT FK1_REPRESENTANTES_DATOS_HISTORICO FOREIGN KEY (ID_REPRESENTANTE_DATOS, CLAVE_ELECTOR) 
	 REFERENCES   REPRESENTANTES.REPRESENTANTES_DATOS(ID_REPRESENTANTE_DATOS, CLAVE_ELECTOR) ,
 	 CONSTRAINT  FK2_PARTIDOS_HISTORICO FOREIGN KEY (ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO) 
	 REFERENCES   PARTIDOSPOLITICOS.PARTIDOS(ID_ESTADO , TIPO_ASOCIACION ,ID_PARTIDO_CANDIDATO)  );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO  IS 'Historico|Tabla de captura la cual contiene un registro de cada una de las operaciones realizadas sobre la tabla representantes_preliminares y genera un histórico de los datos de cada una de sus columnas.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.ID_HISTORICO  IS ' |Identificador de la tabla.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.TIPO_OPERACION  IS ' |Tipo de operacion que se realizo al registro.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.ID_REPRESENTANTE_PRE IS '|Identificador del representante del partido político.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.ID_ESTADO IS '|Identificador del estado (REPRESENTANTES.Representantes) (CASILLAS.CASILLAS).';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES; o bien, el ID_DISTRITO_LOCAL de la tabla DISTRITOS_LOCALES del esquema de GEOGRAFICO.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.TIPO_ASOCIACION IS '1.- Partido Politico, 4.- Candidatura Independiente|Identificador del TIPO de Asociacion Politica en la que podran ser registrados los representantes.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.ID_PARTIDO_CANDIDATO IS '|Identificador del Partido Politico o Candidato Independiente para el que pueden ser registrados los representantes.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.CLAVE_ELECTOR IS '|Número de Credencial de Elector.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_PRELIMINARES_HISTORICO.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
  
--DROP TABLE REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO
 CREATE TABLE REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO ( 
 	ID_HISTORICO  			  DECIMAL(10,0) NOT NULL , 
  	TIPO_OPERACION  		  CHAR(1),  
	ID_REPRESENTANTE_PRE     DECIMAL(10,0) NOT NULL , 
	ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL ,
	ID_ESTADO                DECIMAL(2,0) NOT NULL , 
	ID_DISTRITO_FEDERAL      DECIMAL(2,0) NOT NULL , 
	CALIDAD_REPRESENTANTE    CHAR(1), 
	SECCION                  DECIMAL(5) NOT NULL, 
	TIPO_CASILLA             VARCHAR(6) NOT NULL ,
	USUARIO         		 VARCHAR(50 ) NOT NULL , 
	FECHA_HORA        		 TIMESTAMP (6) NOT NULL , 
	CONSTRAINT PK_REPRESENTANTES_CASILLA_HISTORICO PRIMARY KEY (ID_HISTORICO) ,
	CONSTRAINT FK1_REPRESENTANTES_PRELIMINARES_HISTORICO FOREIGN KEY( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS) REFERENCES  
	REPRESENTANTES.REPRESENTANTES_PRELIMINARES  ( ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS) ON DELETE CASCADE,
	CONSTRAINT FK2_CASILLAS_HISTORICO FOREIGN KEY( ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA) REFERENCES  
	CASILLAS.CASILLAS ( ID_ESTADO, ID_DISTRITO_FEDERAL, SECCION, TIPO_CASILLA)  );
COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO  IS 'Historico| Tabla de captura la cual contiene un registro de cada una de las operaciones realizadas sobre la tabla representantes_casilla y genera un histórico de los datos de cada una de sus columnas.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.ID_HISTORICO  IS ' |Identificador de la tabla.';
    COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.TIPO_OPERACION  IS ' |Tipo de operacion que se realizo al registro.';
    COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.ID_REPRESENTANTE_PRE IS '|Identificador del representantes preliminar (REPRESENTANTES.REPRESENTANTES_PRELIMINARES).';
    COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.ID_ESTADO IS '|Identificador del estado (REPRESENTANTES.Representantes) (CASILLAS.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES; o bien, el ID_DISTRITO_LOCAL de la tabla DISTRITOS_LOCALES del esquema de GEOGRAFICO.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.SECCION IS '|Número de la sección (CASILLAS.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.TIPO_CASILLA IS ' B.- Básica, C.- Contigua |TIPO de casilla. (CASILLAS.CASILLAS).'; 
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.CALIDAD_REPRESENTANTE IS '1;propietario1,  2;propietario2,  3;suplente.|Nivel del representante.';
  	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_CASILLA_HISTORICO.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
  
--DROP TABLE REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO
 CREATE TABLE REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO (  
 	ID_HISTORICO  			  DECIMAL(10,0) NOT NULL , 
  	TIPO_OPERACION  		  CHAR(1), 
	ID_REPRESENTANTE_PRE     DECIMAL(10,0) NOT NULL , 
	ID_REPRESENTANTE_DATOS   DECIMAL(10,0) NOT NULL ,
	ID_ESTADO                DECIMAL(2,0) NOT NULL , 
	ID_DISTRITO_FEDERAL      DECIMAL(2,0) NOT NULL , 
	USUARIO         		 VARCHAR(50 ) NOT NULL , 
	FECHA_HORA        		 TIMESTAMP (6) NOT NULL , 
	CONSTRAINT PK_REPRESENTANTES_GENERALES_HISTORICO PRIMARY KEY (ID_HISTORICO  ) ,
	CONSTRAINT FK1_REPRESENTANTES_PRELIMINARES_HISTORICO FOREIGN KEY( ID_REPRESENTANTE_PRE, ID_REPRESENTANTE_DATOS) REFERENCES  
	REPRESENTANTES.REPRESENTANTES_PRELIMINARES  ( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS) ON DELETE CASCADE );
COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO  IS 'Historico| Tabla de captura la cual contiene un registro de cada una de las operaciones realizadas sobre la tabla representantes_generales y genera un histórico de los datos de cada una de sus columnas.';
    COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.ID_HISTORICO  IS ' |Identificador de la tabla.';
    COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.TIPO_OPERACION  IS ' |Tipo de operacion que se realizo al registro.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.ID_REPRESENTANTE_PRE IS '|Identificador del representantes preliminar (REPRESENTANTES.REPRESENTANTES_PRELIMINARES).';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.ID_ESTADO IS '|Identificador del estado (REPRESENTANTES.Representantes) (CASILLAS.CASILLAS).';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.ID_DISTRITO_FEDERAL IS '|Este campo puede hacer referencia al ID_DISTRITO_FEDERAL de la tabla DISTRITOS_FEDERALES; o bien, el ID_DISTRITO_LOCAL de la tabla DISTRITOS_LOCALES del esquema de GEOGRAFICO.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_GENERALES_HISTORICO.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transaccion por el usuario actualmente conectado.';
  
--DROP TABLE REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO
  CREATE TABLE REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO (
  	 ID_HISTORICO  			  DECIMAL(10,0) NOT NULL , 
  	 TIPO_OPERACION  		  CHAR(1), 	
	 ID_REPRESENTANTE_ACRE 			DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_PRE 			DECIMAL(10,0) NOT NULL , 
	 ID_REPRESENTANTE_DATOS 		  DECIMAL(10,0) NOT NULL ,
	 FECHA_ACREDITACION 			DATE, 
	 ID_RESPONBLE_ACRE 				DECIMAL(10,0) NOT NULL , 
	 HORA_ACREDITACION 				TIME WITHOUT TIME ZONE NOT NULL , 
	 ACTIVO            				CHAR(1) NOT NULL   DEFAULT 'T'  , 
	 USUARIO 						VARCHAR(50 ) NOT NULL , 
	 FECHA_HORA 					TIMESTAMP (6) NOT NULL ,
	 CONSTRAINT PK_REPRESENTANTES_ACREDITADOS_HISTORICO PRIMARY KEY ( ID_HISTORICO ) ,
	 CONSTRAINT FK1_REPRESENTANTES_PRELIMINARES_HISTORICO FOREIGN KEY( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS ) 
	 REFERENCES   REPRESENTANTES.REPRESENTANTES_PRELIMINARES( ID_REPRESENTANTE_PRE , ID_REPRESENTANTE_DATOS) ON DELETE CASCADE );
 COMMENT ON TABLE REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO  IS 'Historico|Tabla de captura la cual contiene un registro de cada una de las operaciones realizadas sobre la tabla representantes_acreditados y genera un histórico de los datos de cada una de sus columnas.';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.ID_HISTORICO  IS ' |Identificador de la tabla.';
    COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.TIPO_OPERACION  IS ' |Tipo de operacion que se realizo al registro.';
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.ID_REPRESENTANTE_ACRE  IS '|Identificador del representante del partido político.';  
 	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.ID_REPRESENTANTE_PRE IS '|Identificador del representantes preliminar (REPRESENTANTES.REPRESENTANTES_PRELIMINARES).';
	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.ID_REPRESENTANTE_DATOS IS '|Identificador del representante del partido político.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.FECHA_ACREDITACION  IS '|Fecha de la acreditacion. .';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.ID_RESPONBLE_ACRE  IS 'O.- OPLE, C.- CD| Identifica quien acredita al representante, OPLE o por Consejo Distrital.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.HORA_ACREDITACION IS 'HH:MM:SS|Hora y minutos con segundo en que se acredita a el representante.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.ACTIVO IS '|Bandera para saber si el representante esta activo o no para la eleccion.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.USUARIO IS '|Usuario del sistema responsable de las transacciones que se registran en el mismo.';
   	COMMENT ON COLUMN REPRESENTANTES.REPRESENTANTES_ACREDITADOS_HISTORICO.FECHA_HORA IS 'DD/MM/YYYY HH24:MI:SS.FF|Fecha y hora hasta microsegundos en que fue realizada la transacción por el usuario actualmente conectado.';
